@@ -30,16 +30,6 @@ class ChangeTypes(enum.Enum):
                 return item
         raise UnsupportedTagException(f'Tag "{tag}" not supported!')
 
-    @staticmethod
-    def get_by_type(change_type: "ChangeTypes") -> "ChangeTypes":
-        """
-        Поиск по типу
-        """
-        for item in ChangeTypes:
-            if item == change_type:
-                return item
-        raise UnsupportedTagException(f'Type "{change_type}" not supported!')
-
     @staticmethod
     def accept_tag() -> List[str]:
         """
