@@ -39,13 +39,16 @@ class Changelog(object):
             raise VersionOverTextException()
 
         if ']-' not in _version_name and len([item for item in _version_name.split("]") if item.strip()]) != 1:
-            raise VersionOverTextException()
+            try:
+                return datetime.datetime.strptime(_version_name.split(']', maxsplit=1)[-1].strip(), "%Y-%m-%d")
+            except Exception as e:
+                raise VersionOverTextException()
 
         if "-" not in _version_name:
             return None
-        split = _version_name.split('-', maxsplit=1)
+
         try:
-            return datetime.datetime.strptime(split[-1].strip(), "%Y-%m-%d")
+            return datetime.datetime.strptime(_version_name.split('-', maxsplit=1)[-1].strip(), "%Y-%m-%d")
         except Exception as e:
             raise VersionDateConvertException()
 
